# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::Gui::List;

use strict;
use GeoDB::Display;
use GeoDB::Utils;
use QWizard;

our @ISA = qw(GeoDB::Display);

our $VERSION = "0.97";

my @extracols = qw(found puzn puzw infield distance);

our @GEOOPTIONS = 
  (
   { name => 'fields',
     title => 'The wayoint fields to list in the table:',
     type => "textbox",
     default => "Ident\nType\nSubtype\nGroundspeak_Owner_Name\nURLNAME",
   },
   { name => 'plugins',
     title => 'A list of extra gui/list plugins to load',
     helpdesc => '(\',\' separated)',
   },
   { name => 'separator',
     title => 'Include a blank space vertical separator between caches',
     type => 'checkbox',
     default => 0,
   },
  );

sub display {
     my ($self, $set, $dbh) = @_;

     my (@pluginlist, @plugins);

     GEODEBUG(3, "Listing a set\n");
     $set->load_parts({ logs => $self->{'options'}{'logs'},
			attributes => 1});
     my @fields;
     if ($self->{'options'}{'fields'} =~ /,/) {
	 @fields = split(/,\s*/,$self->{'options'}{'fields'});
     } else {
	 @fields = split(/\n\s*/,$self->{'options'}{'fields'});
     }
     my $qw = $self->get_qwizard();
     my $keeprunning = 1;

     # get plugin list and load them
     if ($self->{'options'}{'plugins'}) {
	 my $master = $self->get_master();
	 @pluginlist = split(/,/, $self->{'options'}{'plugins'});
	 foreach my $p (@pluginlist) {
	     push @plugins, $master->new_engine($p,
						['Display::Gui::List::Plugin',
						 'Display',
						 'Everywhere']);
	 }
     }

     $qw->merge_primaries({'listdisplay' =>
			   {
			    title => "Displaying Caches",
			    questions =>
			    [
			     {
			      type => 'table',
			      headers => sub {
				  my @x;

				  foreach my $p (@plugins) {
				      push @x, $p->get_early_headers($set);
				  }

				  my @f = (@fields);
				  map {$_ =~ s/groundspeak_//i;} @f;
				  push @x, @f;

				  foreach my $p (@plugins) {
				      push @x, $p->get_late_headers($set);
				  }
				  return [\@x];
			      },
			      values =>
			      [sub {
				    my $table = [];
				    my $set = $_[$#_];
				    my $count = 0;
				    $set->foreach(sub {
						      my $row;
						      my $cache = shift;
						      foreach my $p (@plugins) {
							  push @$row, $p->get_early_columns($cache, $count);
						      }
						      foreach my $field (@fields) {
							  push @$row,
							    $cache->{'data'}{lc($field)};
						      }
						      foreach my $p (@plugins) {
							  push @$row, $p->get_late_columns($cache, $count);
						      }
						      push @$table, $row;
						      foreach my $p (@plugins) {
							  push @$table, $p->get_extra_rows($cache, $count);
						      }
 						      if ($self->{'options'}{'separator'}) {
 							  push @$table, [{type => 'label', text => '', values => ''}];
 						      }
						      $count++;
						  });
				    return [$table];
				}, $set]
			      },
			    ],

			   post_answers => 
			    [sub {
				 $keeprunning = 0;
				 foreach my $p (@plugins) {
				     if ($p->post_answers(@_, $set, $self)) {
					 $keeprunning = 1;
				     }
				 }
			     }]},
			  });
     while ($keeprunning) {
	 $qw->magic('listdisplay');
     }
}


1;

=head1 NAME

gui/list - Display a GUI listing details of a search set

=head1 DESCRIPTION

START HELP

  Example:
  geoqo -s cache:urlname=funny -d gui/list

The gui/list module displays a GUI in a graphical window that lets you
examine the caches within a cache set.

This is only very preliminary work and is subject to greater expansion
in the future.

END HELP

=cut
