# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::Gui::List::Plugin::Attributes;

use strict;

use GeoDB::Display::Gui::List::Plugin;
use QWizard;
use QWizard::API;
use GeoDB::Set;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Display::Gui::List::Plugin);

our $VERSION = "0.97";

our @GEOOPTIONS =
  (
   { name => 'extrarows',
     title => 'New attribute slots to display:',
     default => "3",
   },
   { name => 'nopuz',
     title => 'Do not show puzn/puzw attributes',
     default => 0,
     type => 'checkbox',
   }
  );

sub get_extra_rows {
    my ($self, $cache, $num) = @_;
    my @rows;
    $cache->load_parts({attributes => 1});

    foreach my $attr (sort keys(%{$cache->{'attributes'}})) {
	next if ($attr =~ /^(puzn|puzw)$/ && $self->{'options'}{'nopuz'});
	push @rows,
	  ['',
	   { type => 'label',
	     name => "attrnam$num-$attr",
	     values => "$attr"
	   },
	   { type => 'text',
	     name => "attrval$num-$attr",
	     default => $cache->{'attributes'}{$attr},
	   },
	  ];
    }
    for (my $i = 0; $i < $self->{'options'}{'extrarows'}; $i++) {
	push @rows,
	  ['',
	   { type => 'text',
	     name => "newattrnam$num-$i",
	   },
	   { type => 'text',
	     name => "newattrval$num-$i",
	   },
	  ];
    }
    $rows[0][0] = 'Attributes:';
    return @rows;
}

sub post_answers {
    my ($self, $qw, $set, $listobj) = @_;

    my $count = 0;
    $set->foreach(sub {
		      my ($cache) = @_;
		      my $modified = 0;
		      foreach my $attr (keys(%{$cache->{'attributes'}})) {
			  next if ($attr =~ /^(puzn|puzw)$/ && $self->{'options'}{'nopuz'});
			  if (qwparam("attrval$count-$attr") ne
			      $cache->{'attributes'}{$attr}) {
			      my $val = qwparam("attrval$count-$attr");
			      $cache->set_attribute($attr, $val);
			      GEODEBUG(5,"setting $cache->{'data'}{ident} attribute $attr to $val\n");
			      $modified = 1;
			  }
		      }
		      for (my $i = 0; $i < $self->{'options'}{'extrarows'};
			   $i++) {
			  if (qwparam("newattrnam$count-$i") ne '' &&
			      qwparam("newattrval$count-$i") ne '') {
			      my $name = qwparam("newattrnam$count-$i");
			      my $val = qwparam("newattrval$count-$i");
			      GEODEBUG(5,"setting $cache->{'data'}{ident} attribute $name to $val\n");
			      $cache->set_attribute($name, $val);
			      $modified = 1;
			  }
		      }
		      $count++;
		      $cache->save_attributes();
		  });
    return 0;
}

1;
