# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::Gui::List::Plugin::Show;

use strict;

use GeoDB::Display::Gui::List::Plugin;
use GeoDB::Utils;
use QWizard;
use GeoDB::Set;

our @ISA = qw(GeoDB::Display::Gui::List::Plugin);

use strict;

our $VERSION = "0.97";

sub get_early_headers {
    return 'Show';
}

sub get_buttons {
    my ($self, $cache, $num) = @_;
    my @buttons;

    push @buttons,
      { type => 'checkbox',
	name => 'found' . $num,
	button_label => 'found',
      }
	if (defined($self->{'options'}{'logbutton'}));

    push @buttons,
      { type => 'button',
	name => 'showit',
	default => $num,
	values => 'Show',
      }
	unless (defined($self->{'options'}{'noshow'}));

    push @buttons,
      { type => 'button',
	name => 'logit',
	default => $num,
	values => 'Log',
      }
	if (defined($self->{'options'}{'logbutton'}));

    return @buttons;
}

sub get_early_columns {
    my ($self, $cache, $num) = @_;
    my @res = ();
    @res = $self->get_buttons($cache,$num)
      unless ($self->{'options'}{'logbutton'});
    return @res;
}

sub get_extra_rows {
    my ($self, $cache, $num) = @_;
    my @res = ();
    @res = $self->get_buttons($cache,$num) if ($self->{'options'}{'logbutton'});
    return ['',@res];
}

sub post_answers {
    my $self = $_[$#_];
    my $set = $_[$#_ - 1];

    if (qwparam('showit') ne '') {
	my $cache = $set->get(qwparam('showit'));

	$cache->load({nologs => 1, noattributes => 1});
	if ($self->get_option('showinweb') &&
	    $cache->{'data'}{'type'} eq 'Geocache') {
	    my $browser = $self->get_option('webbrowser') || "firefox";
	    my $id = $cache->{'data'}{'ident'};
	    system("$browser \"http://www.geocaching.com/seek/cache_details.aspx?wp=${id}&Submit6=Go\" &");
	} else {
	    my $nset = new GeoDB::Set;
	    $nset->add($cache);

	    # XXX: can we work around this in a cleaner way?
	    my $master = $self->get_master();
	    my $qw = $master->{'qwizard'};
	    delete $master->{'qwizard'};
	    $master->display($nset, "gui/show",
			     $master->{'dbh'});
	    delete $master->{'qwizard'};
	    $master->{'qwizard'} = $qw;
	    qwparam('showit', 0);
	}
	return 'REDISPLAY';
    } elsif (qwparam('logit') ne '') {

	my $cache = $set->get(qwparam('logit'));

	$cache->load({nologs => 1, noattributes => 1});
	my $browser = $self->get_option('webbrowser') || "firefox";
	my $id = $cache->{'data'}{'id'};
	system("$browser \"http://www.geocaching.com/seek/log.aspx?ID=${id}\" &");
	return 'REDISPLAY';
    } else {
	for (my $i = 0; $i < $set->num(); $i++) {
	    if (qwparam('found' . $i)) {
		my $cache = $set->get($i);
		$cache->set_tag('found');
		print STDERR "tagging $cache->{'data'}{'ident'} as found\n";
	    }
	}
    }
}

1;
