# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::List;

use strict;
use GeoDB::Display;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Display);

our @GEOOPTIONS = 
  (
   { name => 'format',
     help => 'Specifies the formatting parameters' }
  );

our $VERSION = "0.97";

sub display {
     my ($self, $set, $dbh) = @_;

     GEODEBUG(3, "Listing a set\n");
     $set->load_parts({attributes => 1});
     return $set->ssummary($self->{'options'});
}


1;

=head1 NAME

List - List the contents of the search set

=head1 DESCRIPTION

START HELP

  Example 1:
  geoqo -d list
  num GCID     Name
  1   GCMR3M   The Mystery of Livinrgttoo
  2   GCPWBT   Hidden Cactus Garden

  Example 2:
  geoqo -d 'list:format=%{3:count} %{6:ident} terr=%{3:groundspeak_terrain} diff=%{groundspeak_difficulty}'
  1   GCMR3M terr=1.5 diff=1.5
  2   GCPWBT terr=2   diff=1.5

The List display shows the contents of the search Set one line at a
time.  By default, the format is (may vary depending on type though):

  %{3:count} %{8:ident} %{66:urlname}

The number prefix is the number of spaces to print it in and it will
pad with extra spaces if it doesn't fill that space.  If left out,
it'll print it straight out in any length it may be.  Adding a decimal
point will limit it to a maximum of that length.  IE:

  %{20.20:urlname}

Will print B<only> the first 20 characetrs of the urlname.

END HELP

=cut

