# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::Sets;

use strict;
use GeoDB::Display;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Display);

our $VERSION = "0.97";

our @GEOOPTIONS = 
  (
   { name => 'match',
     help => 'Only lists set names containing this value',
     title => 'Optional string to match:',
   }
  );

sub display {
    my ($self, $set, $dbh) = @_;

    GEODEBUG(3, "Displaying the saved database \"Sets\"\n");

    my $sth = $dbh->prepare('select name, count(ident) from sets
                                    group by name order by name');
    $sth->execute();
    my $rows = $sth->fetchall_arrayref;
    my $out;
    $out .= sprintf("%6s %s\n",  'Count', 'Set Name' );
    $out .= sprintf("%6s %s\n",  '-' x 5, '-' x 40 );
    my $match = $self->{'options'}{'match'};
    foreach my $row (@$rows) {
	if (!$match || $row->[0] =~ /$match/) {
	    $out .= sprintf("%6d %-50s\n",  $row->[1], $row->[0]);
	}
    }
    return $out;
}

1;

=head1 NAME

Sets - Display a list of the saved sets

=head1 DESCRIPTION

START HELP

  Example:
  geoqo -d sets
 Count Set Name
 ----- ----------------------------------------
   450 import:Bethel Island
   500 import:Concord
   500 import:Copy of SanFrancisco
 [...]

Shows the list of existing sets remembered by the geoqo system, and
the number of caches in each one.  See the geoqo documentation on
"sets" for further details.

END HELP

=cut
