# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::Show;

use strict;
use GeoDB::Display;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Display);

our $VERSION = "0.97";

our @GEOOPTIONS = 
  (
   { name => 'logs',
     help => 'If true, shows the logs in the output.',
     text => 'Show Log Messages:',
     type => 'checkbox',
     values => [1,0],
     default => 0
   },
  );

sub display {
     my ($self, $set, $dbh) = @_;

     GEODEBUG(3, "Showing a set\n");
     $set->load({nologs => !($self->{'options'}{'logs'})});
     return $set->sdisplay($self->{'options'}{'logs'});
}


1;

=head1 NAME

Show - Show the contents of the search set

=head1 DESCRIPTION

START HELP

  Example 1:
  geoqo -s 1 -d show
Show (-d show) the waypoint details for #3 from the last search (which is
really #3 from the default set or the set specified via the -N
switch):

      > geoqo -s 3 -d show
      GCHW9M     Multi-cache         Location:   38.542933, -121.6998
      Name:      The eyes have it (Yamar's unusual #1)
      Owner:     Yamar                (#183928)  Created:  2004-03-08
      Placed By: yamar
      Rating:    3/1.5
      URL:       http://www.geocaching.com/seek/cache_details.aspx?guid=5f9bd8d4-193a-4e0c-92c4-f107ae6d878b
      Short Description:
        A 3 part waypoint: a virtual, an unusual and a regular

      Long Description:
        Yamar to Spelunk on 2004-04-06:
        "If this cache is under that lamp post [again], I'm going to scream."
        [...]

Show the waypoint details and also the logs (-L, but this may change
in the future):

      > geoqo -s 3 -d show -L
      GCHW9M     Multi-cache         Location:   38.542933, -121.6998
      Name:      The eyes have it (Yamar's unusual #1)
      [...]

      Log #13914681 by Mango101: (Found it)
        This cache took us way too many tries! Finally we found it! TNLN.

      Log #14812407 by Mister Grim & Pooka: (Found it)
        The hint threw us for a loop but we figured it out
        eventually. Thanks for another great cache!
      [...]

END HELP

=cut

