# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::Stats;

use strict;
use GeoDB::Display;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Display);

our $VERSION = "0.97";

sub display {
    my ($self, $set, $dbh) = @_;

    if (!$dbh) {
	my $master = $self->get_master();
	$dbh = $master->{'dbh'};
    }

    my $out;
    GEODEBUG(3, "Displaying Database Statistics\n");
    my $count = select_flat1($dbh,'select count(*) from waypoints');
    $out .= sprintf ("Waypoints:  %7d\n",$count->[0]);
    my $count = select_flat1($dbh,'select count(*) from geocaches');
    $out .= sprintf ("Geocaches:  %7d\n",$count->[0]);
    my $count = select_flat1($dbh,'select count(*) from waymarks');
    $out .= sprintf ("Waymarks:   %7d\n",$count->[0]);
    my $count = select_flat1($dbh,'select count(*) from geodinings');
    $out .= sprintf ("Geodinings: %7d\n",$count->[0]);
    my $count = select_flat1($dbh,'select count(*) from wigles');
    $out .= sprintf ("Wigles:     %7d\n",$count->[0]);
    my $count = select_flat1($dbh,'select count(*) from logs');
    $out .= sprintf ("Logs:       %7d\n",$count->[0]);
    my $names = select_flat1($dbh,'select name from sets group by name');
    $out .= sprintf ("Sets:       %7d\n",$#$names+1);
    my $count = select_flat1($dbh,'select count(*) from tags');
    $out .= sprintf ("Tags:       %7d\n",$count->[0]);
    return $out;
}


1;

=head1 NAME

stats - Display statistics about your database

=head1 DESCRIPTION

START HELP

Example:

  > geoqo -d stats
  Waypoints:     8754
  Geocaches:     8751
  Waymarks:         0
  Logs:         56659
  Sets:            33

The stats display plugin shows statistics about what is contained in
your database.

END HELP

=cut
