# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Export::Gpx;

use strict;
use GeoDB::Export;
use GeoDB::Utils;
use GeoDB::Set;

our $VERSION = "0.97";

our @ISA = qw(GeoDB::Export);

our @GEOOPTIONS =
  ({ name => 'setname',
     help => 'Makes the name field in the gpx file set to this value.',
     title => 'GPX Export Name:',
     default => 'geoqo-export',
   },
   { name => 'nologs',
     help => 'If set the resulting gpx file does not contain the wayoint logs.',
     title => 'Don\'t Export The Logs:',
     type => 'checkbox',
   },
  );

sub _x {
    return GeoDB::Export::_add_basic_entity(@_);
}

sub export_it {
    my ($self, $file, $set) = @_;

    GEODEBUG(1,"writing file: $file\n");
    open(O, ">$file");

    my $datestamp = get_date_stamp();

    # start the header
    # <bounds minlat="38.236517" minlon="-122.04275" maxlat="38.870533" maxlon="-121.271167" />
    print O "<?xml version=\"1.0\" encoding=\"utf-8\"?>
<gpx xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" version=\"1.0\" creator=\"Groundspeak Pocket Query\" xsi:schemaLocation=\"http://www.topografix.com/GPX/1/0 http://www.topografix.com/GPX/1/0/gpx.xsd http://www.groundspeak.com/cache/1/0 http://www.groundspeak.com/cache/1/0/cache.xsd\" xmlns=\"http://www.topografix.com/GPX/1/0\">
  <name>" . _x($self->{'options'}{'setname'}) . "</name>
  <desc>Geocaches exported by GeoDB</desc>
  <author>GeoDB</author>
  <email>geodb-users\@lists.sourceforge.net</email>
  <time>$datestamp</time>
  <keywords>cache, geocache, geodb</keywords>
";

    $set->load_parts({logs => !$self->{'options'}{'nologs'}});
    $set->foreach(sub {
		      my $c=$_[0]{'data'};
		      my $type = ($c->{'subtype'} ? "$c->{'type'}|$c->{'subtype'}" : $c->{'type'});
		      print O "  <wpt lat=\"" . _x($c->{'lat'}) . "\" lon=\"" . _x($c->{'lon'}) . "\">
    <time>" . _x($c->{'time'}) . "</time>
    <name>" . _x($_[0]->ident()) . "</name>
    <desc>" . _x($c->{'desc'}) . "</desc>
    <url>" . _x($c->{'url'}) . "</url>
    <urlname>" . _x($c->{'urlname'}) . "</urlname>
    <sym>" . _x($c->{'sym'}) . "</sym>
    <type>" . _x($type) . "</type>
    <groundspeak:cache id=\"" . _x($_[0]->ident()) . "\" available=\"" . _x($c->{'available'}) . "\" archived=\"" . _x($c->{'archived'}) . "\" xmlns:groundspeak=\"http://www.groundspeak.com/cache/1/0\">
      <groundspeak:name>" . _x($c->{'groundspeak_name'}) . "</groundspeak:name>
      <groundspeak:placed_by>" . _x($c->{'groundspeak_placed_by'}) . "</groundspeak:placed_by>
      <groundspeak:owner id=\"" . _x($c->{'groundspeak_owner_id'}) . "\">" . _x($c->{'groundspeak_owner_name'}) . "</groundspeak:owner>
      <groundspeak:type>" . _x($c->{'groundspeak_type'}) . "</groundspeak:type>
      <groundspeak:container>" . _x($c->{'groundspeak_container'}) . "</groundspeak:container>
      <groundspeak:difficulty>" . _x($c->{'groundspeak_difficulty'}) . "</groundspeak:difficulty>
      <groundspeak:terrain>" . _x($c->{'groundspeak_terrain'}) . "</groundspeak:terrain>
      <groundspeak:country>" . _x($c->{'groundspeak_country'}) . "</groundspeak:country>
      <groundspeak:state>" . _x($c->{'groundspeak_state'}) . "</groundspeak:state>
      <groundspeak:short_description html=\"" . _x($c->{'groundspeak_short_description_html'}) . "\">" . _x($c->{'groundspeak_short_description'}) . "</groundspeak:short_description>
      <groundspeak:long_description html=\"" . _x($c->{'groundspeak_long_description_html'}) . "\">" . _x($c->{'groundspeak_long_description'}) . "</groundspeak:long_description>
      <groundspeak:encoded_hints>" . _x($c->{'groundspeak_encoded_hints'}) . "</groundspeak:encoded_hints>
";
		      if (!$_[1] && exists($_[0]->{'logs'})) {
			  print O "      <groundspeak:logs>\n";
			  foreach my $logid (sort { $a <=> $b } keys(%{$_[0]->{'logs'}})) {
			      my $log = $_[0]->{'logs'}{$logid};
			      print O "        <groundspeak:log id=\"" . _x($log->{'id'}) . "\">
            <groundspeak:date>" . _x($log->{'date'}) . "</groundspeak:date>
            <groundspeak:type>" . _x($log->{'type'}) . "</groundspeak:type>
            <groundspeak:finder id=\"" . _x($log->{'finder_id'}) . "\">" . _x($log->{'finder'}) . "</groundspeak:finder>
            <groundspeak:text encoded=\"" . _x($log->{'text_encoded'}) . "\">" . _x($log->{'text'}) . "</groundspeak:text>
        </groundspeak:log>
";
			  }
			  print O "      </groundspeak:logs>\n";
		      }
		      print O "    </groundspeak:cache>\n";
		      print O "  </wpt>\n";
		  }, $self->{'options'}{'nologs'});
    print O "</gpx>\n";
}

1;

=cut

=head1 NAME

Gpx - export gpx files

=head1 DESCRIPTION

START HELP

  > geoqo -s 'cache:name=cool cache' -e myfile.gpx

The gpx exporter writes out a gpx file containing all the caches in
the search set.

Options are applied between the colon delimiter type specifier (first
part) and the file name (th e last part) like so:

  > geoqo -s 'cache:name=cool cache' -e gpx:nologs=1,setname=boo:myfile.gpx

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut
