# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Import;
use strict;
use GeoDB::Utils;

use GeoDB;

our @ISA = qw(GeoDB);

# can't name this just "import" as that's what perl uses for symbol imports
sub import_it {
    my ($self, $file, $dbh, %opts) = @_;
    my $set = $self->import_set($file, $dbh, %opts);
    $set->set_master($self->get_master());
    $set->{'appendset'} = 1 if ($self->{'options'}{'appendset'});
    $set->save_set($dbh) if (!$self->{'options'}{'dontsave'});
    return $set;
}

sub import_set {
    my $self = shift;
    die "bad import sub-class (self=" . ref($self) . "); import_set not implemented\n";
}

1;

=head1 NAME

Import - import caches from a GeoDB Set

=head1 DESCRIPTION

BEGIN HELP

The importing features within geoqo let you import your waypoints into
the GeoQO database.  See the documentation for the sub-modules for
futher details.

The list of search modules distributed with GeoQO are:

=for comment
START LIST

  Gpx
  Zip
  Dir
  Loc
  Wigle
  System
  Create
  Average

=for comment
END LIST

To see help on any of the above SUBTOPICs, run:

  > geoqo -d help:topic=import/SUBTOPIC

END HELP

=cut
