# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Import::Create;

require GeoDB::Import;
use GeoDB::Utils;
use GeoDB::Set;
use strict;
use QWizard;

our $VERSION = "0.97";

our @ISA = qw(GeoDB::Import);
our @GEOOPTIONS = 
({ name => 'type',
   text => 'Waypoint Type',
   type => 'menu',
   values => sub {
       return ['Waypoint', keys(%GeoDB::Waypoint::registered_types)];
   },
   default => 'Waypoint',
   refresh_on_change => 1,
 },
 { name => 'ident',
 },
 { name => 'setname',
   text => 'Set Name for new Point:',
   default => 'created',
 },
);

#push @GEOOPTIONS, "";
foreach my $wptdata (@GeoDB::Waypoint::waypoint_classcols) {
    next if ($wptdata eq 'type');
    push @GEOOPTIONS,
      { name => $wptdata,
      };
}

foreach my $subclass (keys(%GeoDB::Waypoint::registered_types)) {
    foreach my $wptdata
      (@{$GeoDB::Waypoint::registered_types{$subclass}{'classcolumns'}}) {
	  push @GEOOPTIONS,
	    { name => $wptdata,
	      doif => sub { qwparam('type') eq $subclass },
	    };
    }
}

sub import_set {
    my ($self, $file, $dbh, %opts) = @_;
    GEODEBUG(1,"reading file: $file\n");

    my $waypoint =
      new GeoDB::Waypoint
	({
	  data =>
	  {
	   type => $self->{'options'}{'type'},
	   ident => $self->{'options'}{'ident'},
	   }
	 }
	);
    GEOERR("Failed to create waypoint") if (!$waypoint);

    # loop through all the data possibilities and add them to the
    # object if the user specified them.
    foreach my $opt (@GEOOPTIONS) {
	$waypoint->{'data'}{$opt->{'name'}} =
	  $self->{'options'}{$opt->{'name'}}
	    if ($self->{'options'}{$opt->{'name'}});
    }
    $waypoint->parse_coordinates();
    $waypoint->morph_to_specific();

    # put the results in a set
    my $set = new GeoDB::Set;
    $set->add($waypoint);
    $set->set_name($self->{'options'}{'setname'})
      if($self->{'options'}{'setname'});
    return $set;
}


1;

=head1 NAME

Create - Create new waypoints

=head1 DESCRIPTION

START HELP

  > geoqo -i create:ident=home,lat=N38

The I<create> import plugin lets you create new waypoints and inserts
them into the database.  The list of options is quite long as each
type supported by a given supported waypoint system (geocaching,
geodining, ...) requires an appropriate set of fields.  Running geoqo
simply as:

  > geoqo -i create

should bring up a GUI form which will prompt you for the needed
information.  Leave anything out that isn't appropriate for the
waypoint type you're creating.

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut
