# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Import::Dir;
use Cwd;

require GeoDB::Import::Files;

use GeoDB;
use GeoDB::Utils;
use GeoDB::Set;
use IO::Dir;
use strict;

our $VERSION = "0.97";

our @ISA = qw(GeoDB::Import::Files);

our @GEOOPTIONS = @GeoDB::Import::Files::GEOOPTIONS;

sub import_set {
    my ($self, $file, $dbh, %opts) = @_;
    GEODEBUG(1,"Reading directory: $file\n");

    GEOERR("Not a directory: $file") if (! -d $file);

    # Ok - we opened it, lets make a set to return
    my $set = new GeoDB::Set();
    $set->set_name(($self->{options}{setname}) ? $self->{options}{setname} :
                    "import:" . $file); 

    my $dir = IO::Dir->new($file);
    $self->{'options'}{'allow-missing-engines'} = 1;
    while (my $dfile = $dir->read()) {
	next if (-d $dfile);
	GEODEBUG(5,"trying to load a directory file: $dfile\n");
	$self->handle_file($dbh, $set, "$file/$dfile");
    }

    GEODEBUG(5,$set->num() . " waypoints in set we return.\n");
    return $set;
}

1;

=cut

=head1 NAME

Dir - import a bunch of files from a directory

=head1 DESCRIPTION

START HELP

  > geoqo -i /path/to/directory/

The I<dir> importer allows you to simply specify a directory
("folder") to attempt to read every file from.  It will skip any file
types it does not understand.

END HELP

=head3 Options:

=over

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut
