# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Import::System;
use Cwd;

require GeoDB::Import;

use GeoDB;
use GeoDB::Utils;
use GeoDB::Set;
use GeoDB::Import::Gpx;
use strict;

our $VERSION = "0.97";

our @ISA = qw(GeoDB::Import);

our @GEOOPTIONS = 
(
 { name => 'cmd',
   help => 'It must contain a %{file:TYPE} string that indicates where the output file will be stored, but the path and the name of that file will be created by geoqo.  Example gpsbable arguments would be -o gpx -F %{file:gpx}'},
 { name => 'setname',
   help => 'Uses setname as the name of geoqo SET to create based on the data. Normally this is extracted from the I<name> field within the gpx file itself and prepended with "import:".  IE, if you had a pocket query named "my search" then, when you imported the gpx file into geoqo, you\'d get a new set named "import:my search".  However if your system command doesn\'t properly name the resulting file, this can be used to override it.'},
 { name => 'tmpdir',
   help => 'The temporary directory to use',
   default => $ENV{'HOME'} . "/.geoqo/temp",
 }
);

sub import_set {
    my ($self, $file, $dbh, %opts) = @_;
    GEODEBUG(1,"unsystemping file: $file\n");

    my $tmpdir = $self->{'options'}{'tmpdir'};
    mkdir($tmpdir) if (! -d $tmpdir); 

    my $cmd = $self->{'options'}{'cmd'};

    if ($cmd =~ s/\%{file:([^\}]+)}/\%s/) {
	my $type = $1;
	my $tmpdir = $self->{'options'}{'tmpdir'};
	require File::Temp;
	import File::Temp qw/tempfile/;
	$self->{options}{'suffix'} ||= ".$type";
	$self->{options}{'suffix'} =~ s/:.*//;
	my ($fh, $filename) = tempfile("geoqoXXXXXX", 
				       DIR => $tmpdir,
				       SUFFIX => $self->{options}{'suffix'});
	$fh->close();

        GEODEBUG(5, "running $cmd, %s = $filename\n");
	system(sprintf($cmd, $filename));
	GEODEBUG(6, "return status: $?\n");

	my $engine = $self->new_engine("${type}:nogui=1", 'Import');

	# pass in our set name
	$engine->{'options'}{'setname'} = $self->{'options'}{'setname'}
	  if ($self->{'options'}{'setname'});

	my $tmpset = $engine->import_it($filename, $dbh);

	unlink($filename) unless ($self->{'options'}{'dontdelete'});	

	return $tmpset;
    } else {
	GEOERR("Unable to execute import \"System\" because of missing file specifier");
    }
}

1;

=cut

=head1 NAME

System - import files generated form system commandsq

=head1 DESCRIPTION

START HELP

  > geoqo -i "system:gpsbabel -i garmin -f /dev/ttyS0 -o gpx -F %{file:gpx}"

The I<system> importer allows you to simply specify a command to run
which generates a file of a type that geoqo can actually import.  For
example, the above command runs gpsbabel to import all the waypoints
stored in a GPS on a unix system (/dev/ttyS0 is the name of a serial
device on a linux machine).

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut
