# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Import::Zip;
use Cwd;

require GeoDB::Import::Files;

use GeoDB;
use GeoDB::Utils;
use GeoDB::Set;
use strict;

maybe_load('Archive::Zip', "You need the Archive::Zip perl module to support loading of zip files\n", 'qw(:ERROR_CODES)');

our $VERSION = "0.97";

our @ISA = qw(GeoDB::Import::Files);

our @GEOOPTIONS = @GeoDB::Import::Files::GEOOPTIONS;

sub import_set {
    my ($self, $file, $dbh, %opts) = @_;
    GEODEBUG(1,"unzipping file: $file\n");

    my $tmpdir = $self->{'options'}{'tmpdir'};
    mkdir($tmpdir) if (! -d $tmpdir);
    my $olddir = getcwd();

    my $zip = Archive::Zip->new();
    my $zipstatus = $zip->read($file);

    die "Unable to open $file!\n" if $zipstatus != 'AZ_OK';

    GEODEBUG(5,"File Opened: $file\n");

    # Ok - we opened it, lets make a set to return
#    chdir($tmpdir);
    my $set = new GeoDB::Set();
    $set->set_name(($self->{options}{setname}) ? $self->{options}{setname} :
                    "import:" . $file); 
    # We only care about file types we handle.

    my %wptsetnames;
    $self->{'options'}{'allow-missing-engines'} = 1;
    foreach my $zipmember ($zip->members()) {
      my $zipf = $zipmember->fileName();

      # ensure this is a file the engine can read before we extract it 
      if ($self->check_filename($zipf)) {
	  # we can deal with this file...  extract it.
	  $zip->extractMemberWithoutPaths($zipmember, $tmpdir . "/" . $zipf);
	  GEODEBUG(5,"output to: $tmpdir . / . $zipf\n");
	  GEODEBUG(5,"which doesn't exist\n")
	    if (! -f "$tmpdir/$file");
	  $self->handle_file($dbh, $set, $tmpdir . "/" . $zipf);
	  unlink($tmpdir . "/" . $zipf);
      }
    }

#    chdir($olddir);
    GEODEBUG(5,$set->num() . " waypoints in set we return.\n");
    return $set;
}

1;

=cut

=head1 NAME

Zip - import zipped files

=head1 DESCRIPTION

START HELP

  > geoqo -i myfile.zip

The I<zip> importer allows you to simply specify a zip file for
importing instead of having to unzip it yourself.  It expects the
contents of the zip file to be named similar to the zip file itself,
just like groundspeak sends them out for geocaching.com pocket
queries.  IE, if you import "111111.zip" it'll try to unzip it and
then import the contained 111111.gpx file.  It'll also try to import
the 1111111-wpts.gpx file, if one existed as well.

Note: using this importer requires you to have B<unzip> installed on
your system.

END HELP

=head3 Options:

=over

=item tmpdir=DIR

The zip importer works by copying the zip file to a tmpdir and then
unzipping it there.  This is normally set to I<$HOME/.geoqo/tmpdir>.
This option lets you override that default.

=back

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut
