# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Modify;

use GeoDB;

our @ISA = qw(GeoDB);
our $VERSION = "0.97";

sub modify_set {
    my ($self, $set) = @_;

    my $name = ref($self);
    $name =~ s/.*:://;
    $self->setup_progress($set->num(), "Modifying ($name)");

    my $count = 0;
    my $next = 0;
    $self->set_up($set);
    $set->foreach(sub {
		      $next = $self->set_progress($count++)
			if ($count >= $next);
		      $_[1]->modify($_[0], $_[2]);
		  }, $self, $set);
    $self->clean_up($set);
    $self->stop_progress();
}

# bogus sub for allowing clients to override
sub set_up {
#    my ($self, $set) = 
}

# bogus sub for allowing clients to override
sub clean_up {
#    my ($self, $set) = 
}

1;

=head1 NAME

Modify - export caches from a GeoDB Set

=head1 DESCRIPTION

BEGIN HELP

The exporting features within geoqo let you modify your waypoints in
your search set priory to exporting them or displaying them.  See the
documentation for the sub-modules for futher details.

The list of modify modules distributed with GeoQO are:

=for comment
START LIST

  Solved
  Gctodiff
  Rewrite
  Setattr
  Tag
  Rate
  Makepuzzle
  Delete
  Classify
  Symbol
  Translate
  Distance
  Sortby
  Track
  Diff
  Limit
  Only
  Drop
  Dropexisting
  Load

=for comment
END LIST

To see help on any of the above SUBTOPICs, run:

  > geoqo -d help:topic=modify/SUBTOPIC

END HELP

=cut
