# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Modify::Distance;

use strict;
use GeoDB::Modify;
use GeoDB::Utils;
use GeoDB::Waypoint;

our @ISA = qw(GeoDB::Modify);

our @GEOOPTIONS = (
		   { name => 'from',
		     help => 'The waypoint name distances should be calculated from',
		   },
		   { name => 'n',
		     help => 'The North coordiante to calculate distance from'
		   },
		   { name => 'w',
		     help => 'The West coordiante to calculate distance from'
		   },
		  );

our $VERSION = "0.97";

sub set_up {
    my ($self, $set) = @_;

    if ($self->{'options'}{'from'}) {
	my $waypoint =
	  new GeoDB::Waypoint({ data => 
				{'ident' => $self->{'options'}{'from'}}
			      });
	$waypoint->morph_to_specific();
	$waypoint->load_parts();
	$self->{'n'} = $waypoint->{'data'}{'lat'};
	$self->{'w'} = $waypoint->{'data'}{'lon'};
    } else {
	($self->{'n'}, $self->{'w'}) =
	  parse_coords($self->{'options'}{'n'},$self->{'options'}{'w'});
    }
}


sub modify {
    my ($self, $cache) = @_;

    $cache->load_parts();

    $cache->{'data'}{'distance'} =
      calc_distance($self->{'n'}, $self->{'w'},
		    $cache->{'data'}{'lat'}, $cache->{'data'}{'lon'});
}

1;

=head1 NAME

Distance - Sets distance fields within the cache data

=head1 DESCRIPTION

START HELP

The distance modify plugin puts distance information from a given lat,
lon coordinate and inserts the data into the "distance" field of the
waypoint.  You can then use it in other ways like in I<rewrite>
modification engines or in list formatting, etc.

  > geoqo -s ident:GCABCD -d 'list:format=%{ident} %{distance}

You can calculate distance from coordinates:

  > geoqo -s ident:GCABCD -m 'distance:n=n38 12.123,w=w42 22.333'

or from another waypoint already in the DB:

You can calculate distance from coordinates:

  > geoqo -s ident:GCABCD -m 'distance:from=GCABCD'

END HELP

=cut
