# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Modify::Drop;

use strict;
use GeoDB::Modify;

our @ISA = qw(GeoDB::Modify);
our $VERSION = "0.97";

sub modify {
    my ($self, $cache, $set) = @_;

    $cache->load_parts({attributes => 1});
    foreach my $opt (@{$self->{'optionsarray'}}) {
	my $name = $opt->[0];
	my $type = 'data';
	$type = 'attributes' if ($name =~ s/^attr://);
	if ($opt->[2] eq '<>') {
	    if ($cache->{$type}{$name} ne $opt->[1]) {
		push @{$self->{'dropidents'}}, $cache->{'data'}{'ident'};
	    }
	}
	elsif ($opt->[2] eq '=') {
	    if ($cache->{$type}{$name} eq $opt->[1]) {
		push @{$self->{'dropidents'}}, $cache->{'data'}{'ident'};
	    }
	}
	elsif ($opt->[2] eq '=-') {
	    if (!exists($cache->{$type}{$name})) {
		push @{$self->{'dropidents'}}, $cache->{'data'}{'ident'};
	    }
	}
	elsif ($opt->[2] eq '=+') {
	    if (exists($cache->{$type}{$name})) {
		push @{$self->{'dropidents'}}, $cache->{'data'}{'ident'};
	    }
	}
    }
}

sub clean_up {
    my ($self, $set) = @_;
    foreach my $ident (@{$self->{'dropidents'}}) {
	$set->remove_by_ident($ident);
    }
}

1;

=head1 NAME

Drop - Drops certain caches from the set based on criteria

=head1 DESCRIPTION

START HELP

This is most useful when doing really complex exporting.  See Yamar's
usage description on the web page for why this is helpful sometimes.

The Drop modifier is a compliment to the only modifier.  Generally the
"only" modifier will be easier for most people to think about, but
technically you only need one as they can both accomplish the same
tasks with inverse logic.

The argument formatting is:

  drop:field=value

where field is the field (or attribute prefixed with 'attr:') name,
and value is the exact value.  The valid match types are:

=over

=item  drop:field=value

Matches only if exactly the same.

=item drop:field<>value

Matches if the field B<is not> that value

=item drop:field=-

Matchs if the field doesn't exist.  I use this like follows:

  #
  # unknown caches with solved puzzle coords
  #
  drop:subtype<>Unknown Cache
  +drop:attr:puzn=-
  +solved:
  +gpx:nologs=1:palm-solved.gpx

To drop any unknown cache that a 'puzn' attribute hasn't been added to
it (see the I<Solved> modify plugin for details).

=item drop:field=+

Same as =- but only drops it if it does exist.

=back

END HELP

=cut
