# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Modify::Dropexisting;

use strict;
use GeoDB::Modify;

our @ISA = qw(GeoDB::Modify);
our $VERSION = "0.97";

our @GEOOPTIONS =
  (
   { name => 'prefix',
     title => 'Prefix replacement:',
     helpdesc => 'Replaces first N letters with N prefix letters',
     default => '',
     helptext => 'This is useful to counteract the effects of the gctodiff plugin after it has been applied.',
   },
   { name => 'onlyprefixold',
     title => 'Only prefix for searching:',
     helpdesc => 'Does not re-prefix new waypoints',
     default => '1',
     type => 'checkbox',
   },
  );

my $dbh;
sub set_up {
    my ($self, $set) = @_;
    my $master = $self->get_master();
    my $dbh = $master->{'dbh'};
    $self->{'getidh'} = $dbh->prepare('select count(ident) from waypoints
                                              where ident = ?');
    if ($self->{'options'}{'prefix'}) {
	$self->{'prefixregexp'} =
	  '^' . ('.' x length($self->{'options'}{'prefix'}));
    }
}

sub modify {
    my ($self, $cache, $set) = @_;

    my $ident = $cache->{'data'}{'ident'};
    if ($self->{'prefixregexp'}) {
	$ident =~
	  s/$self->{'prefixregexp'}/$self->{'options'}{'prefix'}/;
    }
    $self->{'getidh'}->execute($ident);
    my $row = $self->{'getidh'}->fetchrow_arrayref;
    if ($row->[0] > 0) {
	push @{$self->{'dropidents'}}, $cache->{'data'}{'ident'};
    } elsif (!$self->{'options'}{'onlyprefixold'}) {
	$cache->{'data'}{'ident'} = $ident;
    }
    $self->{'getidh'}->finish;
}

sub clean_up {
    my ($self, $set) = @_;
    foreach my $ident (@{$self->{'dropidents'}}) {
	$set->remove_by_ident($ident);
    }
}

1;

=head1 NAME

Drop - Drops all caches in a set that already exist in a database.

=head1 DESCRIPTION

START HELP

This modify function is really only useful during an import before a data save.

The plugin simply removes all data from the current set that already
exists in the database.  This can be used to import data where only
the new data is desired.

Example:

  > geoqo -i 'myfile.gpx+dropexisting'

END HELP

=cut
