# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Modify::Limit;

use strict;
use GeoDB::Modify;

our @ISA = qw(GeoDB::Modify);
our $VERSION = "0.97";

our @GEOOPTIONS =
({ name => 'number',
   title => 'Number to waypoints to limit to:',
   default => 100
 },
 { name => 'offset',
   title => 'Offset from the first to start at:',
   default => 0
 });

sub modify_set {
    my ($self, $set) = @_;

    if ($self->{'options'}{'offset'}) {
	# remove everything between 0 and the offset, then limit to the number
	$set->splice(0, $self->{'options'}{'number'});	
    }
    # remove everything beyond the number
    $set->splice($self->{'options'}{'number'});
}

1;

=head1 NAME

Limit - Limits the number of waypoints in a set

=head1 DESCRIPTION

START HELP

This module limits the number of waypoints in a set to a certain
number (starting at an optional certain point in the list of waypoints).

IE, it starts at the I<offset>th waypoint in the set being modified,
and limits the total number to I<number>, stripping off all of the
waypoints before the I<offset> first and then everything from
offset+number next.

If just I<number> is specified (the common case) the firest I<number>
waypoints are kept.

If there are 250 caches in the set:

=over

=item number = 100, offset = 0

Will get the first 100 caches

=item number = 100, offset = 100

Will get the next 100.

=item number = 100, offset = 200

Will get the last 50.

=back

This module is very useful when combined with the distance and sortby
modify pluigns to get the top 10 caches (for example) near something:

  geoqo -s 'set:import:mypocketquery' -m distance:from=GCABCD+sortby:+limit:10

END HELP

=cut
