# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Modify::Makepuzzle;

use strict;
use GeoDB::Modify;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Modify);

our $VERSION = "0.97";

our @GEOOPTIONS = 
  (
   { name => 'nattr',
     help => 'The name of the attribute storing the new north coordinate',
     default => 'puzn'},
   { name => 'wattr',
     help => 'The name of the attribute storing the new west coordinate',
     default => 'puzw'},
   { name => 'reextract',
     help => 'Force rextraction of the equation wiping out the existing data',
     type => 'checkbox',
     default => 0
   },
  );

sub check_for_equation {
    my ($cache, $long, $letter, $done) = @_;

    # don't double do
    next if ($cache->get_attribute($letter,1) ne '');
    next if ($done->{$letter});
    $done->{$letter} = 1;

    my $equation = "";
    if ($long =~ /$letter\s*=\s*([- \t\+\*\/\.–A-Z0-9]+)/) {
	# found an equation for that letter!
	my $eq = $1;

	# deal with certain utf-8 chars (sigh)
	$eq =~ s/–/-/;

	while ($eq =~ s/([^a-zA-Z]*)([a-zA-Z])//) {
	    my $let = $2;
	    $equation .= $1 . '(' . $let . ')';
	    check_for_equation($cache, $long, $let, $done);
	}
	$equation .= $eq;

	if ($equation =~ /[a-zA-Z]/ && $equation =~ /[-\+\*\\]/) {
	    # ensure equation contains at least one other letter and
	    # one operator
	    $equation = "math:$equation";
	    $cache->set_attribute($letter, $equation);
	} else {
	    $cache->set_attribute($letter, '');
	}
    } else {
	$cache->set_attribute($letter, '');
    }
    return $equation;
}

sub parse_for_letters {
    my ($cache, $array, $long, $done) = @_;
    my $count = 0;

    # map everything but the leading letter (eg N/S/E/W)
use Data::Dumper;
    for (my $i = 1; $i <= $#$array; $i++) {
	$array->[$i] =~ s/\n/ /g;
	if ($array->[$i] =~ /^([a-zA-Z])$/) {
	    check_for_equation($cache, $long, $array->[$i], $done);
	    $array->[$i] = "(" . $array->[$i] . ")";
	    $count++;
	}
    }
    return $count;
}

sub setup_attribute {
    my ($cache, $array, $attribute, $long, $done) = @_;

    my $count = parse_for_letters($cache, $array, $long, $done);
    my $string = join("",@$array);
    $string = "replace:$string" if ($count);
    $cache->set_attribute($attribute, $string);
}

sub modify {
    my ($self, $cache) = @_;
    my %done;

    $cache->load_parts({attributes => 1});

    my $long =
      format_output($cache->{'data'}{'groundspeak_long_description'},
		    $cache->{'data'}{'groundspeak_long_description_html'});
    my @parts;

    if (($self->{'options'}{'reextract'} ||
	 !$cache->get_attribute($self->{'options'}{'nattr'},1))
	&& (@parts = ($long =~ /([NS])\s?([A-Z0-9a-z])([A-Z0-9a-z])(?:°||.|)(\s)([A-Z0-9a-z])([A-Z0-9a-z])(\.)([A-Z0-9a-z])([A-Z0-9a-z])([A-Z0-9a-z])/)) > -1) {

	setup_attribute($cache, \@parts, $self->{'options'}{'nattr'},
			$long, \%done);
    }

    if (($self->{'options'}{'reextract'} ||
	 !$cache->get_attribute($self->{'options'}{'wattr'},1))
	&& (@parts = ($long =~ /([EW])\s?([A-Z0-9a-z]?)([A-Z0-9a-z])([A-Z0-9a-z])(?:°||.|)(\s)([A-Z0-9a-z])([A-Z0-9a-z])(\.)([A-Z0-9a-z])([A-Z0-9a-z])([A-Z0-9a-z])/)) > -1) {

	setup_attribute($cache, \@parts, $self->{'options'}{'wattr'},
			$long, \%done);
    }
}

1;

=head1 NAME

Solved - Extracts puzzle coordinates and equations from a cache

=head1 DESCRIPTION

START HELP

This plugin extracts puzzle coordinates and equations from a cache
description and sets up some attributes for doing the puzzle solving.
If a cache description has text in it like "N38 AB.CDE" then this
plugin will create 5 attributes A-E and a "puzn" attribute with the
text "replace:N38 (A)(B).(C)(D)(E)" so that merely by filling in the
A-E attributes will complete the puzzle.

END HELP

=cut
