# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Modify::Sortby;

use strict;
use GeoDB::Modify;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Modify);

our @GEOOPTIONS = (
		   { name => 'sortby',
		     help => 'Field to sort by',
		     default => 'distance',
		   }
		  );

our $VERSION = "0.97";

sub modify_set {
    my ($self, $set) = @_;

    $set->load_parts({attributes => 1});
    my $field = $self->{'options'}{'sortby'};
    my $type = 'data';
    if ($field =~ s/^attr://) {
	$type = 'attributes';
    }
    $set->sortby(sub ($$) { 
		     $_[0]->{$type}{$field} <=> $_[1]->{$type}{$field}
		 });
}

1;

=head1 NAME

Sortby - Reorders a set of caches based on sort criteria

=head1 DESCRIPTION

START HELP

The sort by function sorts data in a set by a particular field.

  > geoqo -s SOMETHING -m sortby:groundspeak_terrain -l

END HELP

=cut
