# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Search::Ident;

use strict;
use GeoDB::Search;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Search);

our $VERSION = "0.97";

our @GEOOPTIONS =
  (
   { name => 'idents',
     help => 'A comma separated list of identifiers to search for'
   }
  );

our %GEOINFO = 
  ( allowextraargs => 1 );

sub search {
     my ($self, $criteria, $type) = @_;

     $criteria = $self->{'options'}{'idents'}
       if($criteria eq 'ident');
     GEODEBUG(3, "searching for idents: $criteria\n");
     my @idents = split(/,/,$criteria);
     map { $_ = "\%$_"; } @idents;
     my $whereclause = "(waypoints.ident like ?" . (" or waypoints.ident like ?" x $#idents) . ")";
     return $whereclause, \@idents;
}


1;

=head1 NAME

Ident - Searches by a list of id

=head1 DESCRIPTION

START HELP

  > geoqo -s ident:gcabcd,gcefgh,gcijkl -d count
  Search/Set Count: 3

  > geoqo -s ident:abcd,efgh,ijkl -d count
  Search/Set Count: 3

The I<ident> plugin merely lets you quickly list a bunch of waypoint
identifiers you want to select with geodb.

The identifiers do have a wild card inserted before them so you can
leave off a common prefix, as shown in the second example above, and
still match the list (saves typing).

Really, the I<ident:> search type is just a faster way to type:

  > geoqo -s waypoint:ident=abcd||waypoint:ident=efgh||...

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut

