# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Search::Set;

=cut

=head1 NAME

Set - search waypoints based on sets

=head1 SYNOPSIS

  > geoqo -s "set:import:my query"
  Search Result Count: 500

=head1 DESCRIPTION

START HELP

Sets, which are described further below, are a bunch of waypoints all
with an identically named "tag".  As an example, if your
geocaching.com pocket query was named "my query" and you import it
into geoqo using the -i switch the waypoints contained in that gpx file
will be assigned to the "import:my query" set.  You can use the
I<set:setname> search type to load these waypoints.

  > geoqo -s "set:import:my query" -d count
  Search Result Count: 500

This command would count everything in the database that was in the
"import:my query" set name (that was likely imported from a pocket
query).  See the Advanced Searching section in the geoqo documentation
for other examples of combining I<set:> searches and I<waypoint:> (or
other) searches so you can search for "all waypoints matching a
criteia within a set" for example.

If you prefix the name with a minus sign (-) then it will include all caches B<NOT> in that set.  For example to find all caches that are in seta but not in setb then the following expression would accomplish that:

    > geoqo -s 'set:seta&&set:-setb'

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut

require GeoDB::Search;
use GeoDB::Utils;
use strict;

our $VERSION = "0.97";

our @ISA = qw(GeoDB::Search);

sub search {
    my ($self, $list) = @_,;
    GEODEBUG(3, "search sets: $list\n");
    my $clause = "";
    my @args = ();
    my $not = '';
    my @sets = split(/,/,$list);
    foreach my $set (@sets) {
	$clause .= ' or name = ?';
          $not = " not " if ($set =~ s/^-//);
          push @args, $set;
    }
    $clause =~ s/ or /waypoints.ident $not in (select distinct ident from sets where /;
    $clause .= ')';
    return ($clause, \@args);
}

1;
