# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Search::Tag;

=cut

=head1 NAME

Tag - search waypoints by tags

=head1 SYNOPSIS

geoqo -s tag:tag=cool -l

=head1 DESCRIPTION

START HELP

Tag searches tags that you yourself or others have placed on a cache.

You can place them using the Tag Modify plugin:

  > geoqo -s ident:gcabcd -m tag:cool/awesome

  > geoqo -s tag:cool -d count:
  Search Result Count: 1

Prefix the tag names with "mine:" if you want to search just you tags,
or "others:" if you want to search other people's tags.

  > geoqo -s tag:mine:cool -d count:
  Search Result Count: 1

  > geoqo -s tag:others:cool -d count:
  Search Result Count: 2

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut

use GeoDB::Utils;

use strict;

our @ISA = qw(GeoDB::Search);

our $VERSION = "0.97";

sub search {
    my ($self, $criteria, $type) = @_;

    GEODEBUG(3, "search tags: $criteria\n");
    my $clause = "";
    my @args = ();
    my $not = '';
    my @tags = split(/,/,$criteria);
    foreach my $tag (@tags) {
	$clause .= ' or (tagname = ?';
	$not = " not " if ($tag =~ s/^-//);
	$clause .= " and ismine = 1" if ($tag =~ s/^mine://);
	$clause .= " and count > 0" if ($tag =~ s/^others://);
	push @args, $tag;
	$clause .= ')';
    }
    $clause =~ s/ or /waypoints.ident $not in (select distinct ident from tags where /;
    $clause .= ')';
    return ($clause, \@args);

}

1;
