# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Search::Wigle;

use strict;
use GeoDB::Search;
use GeoDB::Utils;
use GeoDB::Waypoint;

our @ISA = qw(GeoDB::Search);

our $VERSION = "0.97";

sub search {
     my ($self, $criteria, $type) = @_;

     GEODEBUG(3, "passing criteria: $criteria\n");
     return
       $self->get_search_tokens( $criteria, $type,
				 get_waypoint_type_cols_and_map('Wigle'),
				 "type == 'Wigle' and");
}


1;

=head1 NAME

Wigle - query the waypoint list for wigle attributes

=head1 DESCRIPTION

START HELP

  > geoqo -s wigle:name=unusual -d count
  Search/Set Count: 6

Searches the database for only waypoints that are of type 'Wigle'
and conform to the terms given.  See the documentation on the
waypoint: search type for further details on how to use it, because
everything else is the same.

Possible search columns for wigles include the following beyond
those listed in the waypoint section:

			   wigle_ssid
			   wigle_netid
			   wigle_discover
			   wigle_channel
			   wigle_type
			   wigle_freenet
			   wigle_firsttime
			   wigle_sep
			   wigle_comment
			   wigle_qos
			   wigle_lastupdt
			   wigle_paynet
			   wigle_userfound

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut

