# Copyright (C) 2007 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Waypoint::Waymark;

use strict;
use GeoDB::Utils;
use GeoDB::Waypoint;

our $VERSION = "0.97";
our @ISA=qw(GeoDB::Waypoint);

# database handles
my ($getcacheh, $getidh, $newwayidh, $updatewh,
    $logdelh, $logaddh, $logselh, $logselfh);

# 'ident' not listed intentionally
our @waymark_dbcols = qw(
			  waymark_owner_name
			 );

# 'ident' not listed intentionally
our @waymark_class_cols = qw(
			      waymark_owner_name
			     );

our @waymark_waypoint_cols = (
			       @GeoDB::Waypoint::waypoints_dbcols,
			       @waymark_dbcols
			      );

sub init {
    my $dbh = shift;

    return if (!$dbh);

    # waymark handles
    $getidh   = $dbh->prepare_cached('select ident from waymarks
                                       where ident = ?');

    $newwayidh   = $dbh->prepare_cached('insert into waymarks(' .
				      join(", ", @waymark_dbcols) .
				      ', ident) values(' .
				      ("?, " x ($#waymark_dbcols + 1)). " ?)");

    $updatewh   = $dbh->prepare_cached('update waymarks set ' .
				       join(" = ?, ", @waymark_dbcols) .
				       ' = ? where ident = ?');

    GeoDB::Waypoint::register_waypoint_type('Waymark',
					    'GeoDB::Waypoint::Waymark',
					    'waymarks',
					    \@waymark_dbcols,
					    \@waymark_class_cols);

    return 1;
}

sub new {
    my $type = shift;
    my ($class) = ref($type) || $type;
    my $self;
    if (ref($_[0]) eq 'HASH') {
	$self = $_[0];
    } else {
	my %self = @_;
	$self = \%self;
    }
    return if (!$self->{'data'}{'ident'}); # required field
    bless($self, $class);
}

# if it already exists in the db, return 1
sub typedata_exists {
    my ($self) = @_;
    $getidh->execute($self->{'data'}{'ident'});
    my $row = $getidh->fetchrow_arrayref();
    $getidh->finish();
    return 1 if $row;
    return 0;
}

# save the current cache to the DB (either update or insert a new row)
sub save {
    my $self = shift;
    my $modgh = $newwayidh;
    # save to db

    $self->SUPER::save(@_);

    if ($self->typedata_exists()) {
	GEODEBUG(6,"updating waymark $self->{data}{ident}\n");
	$modgh = $updatewh;
    } else {
	GEODEBUG(6,"inserting waymark $self->{data}{ident}\n");
    }
    my $data = $self->{'data'};

    $modgh->execute($data->{'waymark_owner_name'},
		    $data->{'ident'},
		  );
    if ($modgh->errstr) {
	GEOERR("Error saving $data->{ident}: " . $modgh->errstr . "\n");
    }
}

sub ssummary {
    my ($self, $count, $options) = @_;

    return $self->sprint_summary_line($count, ($options->{'format'} ? "$options->{'format'}\n" : "%{3:count} %{8:ident} %{66:desc}\n"));
}

sub sdisplay {
    my ($self, $dologs) = @_;
    my $data = $self->{'data'};
    my $out;
    $out .= sprintf("%-8s   %-31s Location:  %s, %s\n",
	   $data->{'ident'}, $data->{'type'} . " / " . $data->{'subtype'},
	   sprint_coords($data->{'lat'}, $data->{'lon'}));
    $out .= sprintf("Name:      %s\n", $self->{'data'}{'urlname'});
    my $time = $data->{'time'};
    $time =~ s/T.*//;
    $out .= sprintf("Created:   %s\n", $time,);
    $out .= sprintf("Owner:     %s\n", $data->{'waymark_owner_name'});
    $out .= sprintf("URL:       %s\n", $data->{'url'});
    $out .= sprintf("Descript:  %s\n", $data->{'desc'});
    $out .= $self->sshow_attributes();
    $out .= $self->sshow_tags();
    $out .= $self->sshow_ratings();
    $out .= $self->sshow_logs() if ($dologs);
    return $out;
}

sub remove_from_specific_tables {
    my $self = shift;
    $self->remove_from_a_table_by_ident('geocaches');
}

1;
