#!/usr/bin/perl

use strict;

my $outputfile = "./install_modules";

our @required = qw(
  XML::Parser
  XML::Simple
  DBI
  DBD::SQLite2
  Text::Balanced
);

our %optional = (
		 'IO::String' =>
		 'Needed to use the online help system',

		 'HTML::FormatText' => 
		 'formats cache HTML descriptions to text',

		 'Text::Wrap' => 
		 'wraps text nicely on the screen',

		 'WWW::Babelfish' =>
		 'translate languages in cache fields to different languages',

		 'Class::MethodMaker' =>
		 'Also required for progress bars:',

		 # doesn't even work on windows?
		 'Term::ProgressBar' => 
		 'for getting a progress bar display as it performs tasks',

		 'Archive::Zip' =>
		 'for Zip import format to work',

		 'LWP::UserAgent' =>
		 'for publishing and fetching tags and ratings to the server',
		);

our %gui =
  ('QWizard' =>
   'Question and Answer Wizard module',

   'Glib' =>
   'Low-level support for things needed for the Gtk2-based GUI interface.',

   'Gtk2' =>
   'A Graphical front end.  Ideally you want this; but Tk will be ok too.',

   'Tk' =>
   'A Graphical front end.  You don\'t need both Gtk2 and Tk.  Pick one.',

   # GD -- instructions needed too (just use all defaults?
   'GD' =>
   'Graphics Drawing package (required for graphs)',

   # ack:requires compiler)
   'Chart::Lines' =>
   'If you want to display graphs',

   'Getopt::GUI::Long' =>
   'Command line help info if you use the command line invocation',
  );

our @classifiers =
  (
   'Lingua::PT::Stemmer',
   'Lingua::Stem::It',
   'Lingua::Stem::Snowball::No',
   'Text::German',
   'Lingua::Stem::Snowball::Se',
   'Lingua::Stem::Fr',
   'Lingua::GL::Stemmer',
   'Lingua::Stem::Snowball::Da',
   'Lingua::Stem::Ru',

   'Params::Validate',
   'Lingua::Stem',
   'Algorithm::NaiveBayes',
   'Class::Container',
   'Statistics::Contingency',

   'AI::DecisionTree',

   # fails to build
   'Algorithm::SVM',

   'Module::Build',
   'AI::Categorizer',
   'AI::Categorizer::Collection::Files',
   'AI::Categorizer::Collection::InMemory',
   'AI::Categorizer::Learner::NaiveBayes',
   'AI::Categorizer::Learner::DecisionTree',
   'AI::Categorizer::Learner::SVM',
   'File::Spec',
  );

our %classifiers;
map { $classifiers{$_} = 'Needed for doing smart cache classification.';
  } @classifiers;


our %groups = 
  ( 'AMiscellanious' => \%optional,
    'BGraphical User Interface' => \%gui,
    'CSmart Cache Classification' => \%classifiers,
  );

# Fix broken issues on windows
if ($^O eq 'MSWin32') {
    $gui{'Gtk2'}              = "BROKEN:$gui{'Gtk2'}";
    $gui{'Glib'}              = "BROKEN:$gui{'Glib'}";
    $optional{'Term::ProgressBar'}  = "NOTNEEDED:$gui{'Term::ProgressBar'}";
    $optional{'Class::MethodMaker'} = "NOTNEEDED:$gui{'Class::MethodMaker'}";
#    $gui{'GD'}           = "BROKEN:$gui{'GD'}";
#    $gui{'Chart::Lines'} = "BROKEN:$gui{'Chart::Lines'}";
    delete $groups{'CSmart Cache Classification'};
}

my $install = 0;

if ($ARGV[0] eq '--install') {
    $install = 1;
    shift;
    require CPAN;
}


my $havebasics = 1;

do_check($install);

sub do_check {
    $install = shift;
    if ($install) {
	eval { require CPAN; } ||
	  die "could not load the CPAN module for installing things\n";
    }

    print "\nChecking required modules:\n";
    foreach my $m (@required) {
	my $haveit = eval "require $m;";
	if ($haveit) {
	    printf("    %-50s %s\n", $m, "   you have it");
	} else {
	    printf("    %-50s %s\n", $m, "** YOU NEED IT");
	    maybe_install($m);
	    my $haveitnow = eval "require $m;";
	    if (!$haveitnow) {
		$havebasics = 0;
	    }
	}
    }

    if (!$havebasics) {
	if ($install) {
	    print "\nYou need some of the above modules to get GeoQO working\n";
	    print "I tried but failed to install them; you'll need to seek\n";
	    print "help or correct the problems yourself...\n\n";
	} else {
	    print "\nYou need at least the above modules to get GeoQO working\n";
	    print "Once you have installed them, you can run this script to list\n";
	    print "extra modules you may or may not want as well\n\n";
	    print_instructions();
	}
	return;
    }

    print "\nChecking optional modules:\n";

    my $haveeverything = 1;
    foreach my $name (sort keys(%groups)) {
	my $n = $name;
	$n =~ s/^.//;
	print "\n  $n:\n";
	foreach my $m (keys(%{$groups{$name}})) {
	    if ($groups{$name}{$m} =~ /^NOTNEEDED:(.*)/) {
		next;
	    }
	    my $haveit = eval "require $m;";
	    if ($haveit) {
		printf("    %-50s %s\n", $m, "   you have it");
	    } else {
		if ($groups{$name}{$m} =~ /^BROKEN:(.*)/) {
		    printf("    %-50s %s\n      (%s)\n", $m, "** BROKEN ON YOUR OS", ($1 . ")\n      (there is an issue with this module on your operating system; sorry"));
		    next;
		}
		printf("    %-50s %s\n      (%s)\n", $m, "** YOU MAY WANT IT", $groups{$name}{$m});
		maybe_install($m);
		my $haveitnow = eval "require $m;";
		if (!$haveitnow) {
		    $haveeverything = 0;
		}
	    }
	}
    }
    print "\n";

    if (!$haveeverything) {
	print "You may wish to install some or all of the above missing optional modules\n";
    }
    print_instructions($haveeverything);
}

sub maybe_install {
    my ($m) = @_;
    my $haveit = 0;
    if ($install) {
	if ($^O eq 'MSWin32') {
	    printf("      trying to install $m with PPM first...\n");
	    system("ppm install $m");
	    $haveit = eval "require $m;";
	}
	if (!$haveit) {
	    printf("      trying to install $m from CPAN...\n");
	    CPAN::install($m);
	}
    }
}

sub print_instructions {
    my $x = shift;
    if (!$x) {
	print "Attempt to install the above modules? (Y/N)\n";
	my $ans = <STDIN>;
	chomp($ans);
	if ($ans !~ /^y/i) {
	    exit;
	}
	do_check(1);
	print "\n\nRe-examining installed modules\n\n";
	do_check(0);
    } else {
	print "CONGRATULATIONS!  You have all the geoqo prerequisites you could hope for.\n  You may now install GeoQO itself \n\n";
	if ($^O eq 'MSWin32') {
	    print "---Hit ENTER to continue---\n";
	    my $bogus = <STDIN>;
	}
    }
    exit;
}

